You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by Kare Nuorteva <ka...@satama.com> on 2000/01/03 00:08:03 UTC

[PATCH] jakarta-tools/ant/src/main/org/apache/tools/ant/taskdefs/Property.java

some fixes and docs.

Index: Property.java
===================================================================
RCS file:
/home/cvspublic/jakarta-tools/ant/src/main/org/apache/tools/ant/taskdefs/Property.java,v
retrieving revision 1.3
diff -u -r1.3 Property.java
--- Property.java       1999/12/12 17:41:01     1.3
+++ Property.java       2000/01/02 23:04:10
@@ -54,27 +54,38 @@
 
 package org.apache.tools.ant.taskdefs;
 
-import org.apache.tools.ant.*;
-import java.io.*;
-import java.util.*;
+import org.apache.tools.ant.Task;
+import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.ProjectHelper;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.InputStream;
+import java.util.Enumeration;
+import java.util.Properties;
+
 /**
  * Will set a Project property. Used to be a hack in ProjectHelper
  *
  * @author costin@dnt.ro
  */
 public class Property extends Task {
-    String name;
-    String value;
-    String file;
-    String resource;
+    private String name;
+    private String value;
+    private String file;
+    private String resource;
 
     // needs to be set at XML-reading time,
     // no runtime action
     public void execute() throws BuildException {
     }
 
     // XXX ugly - needs to be fixed
-    /** Called after each setter, will set the property at read-time
+    /**
+     * Called after each setter, will set the property at read-time
      */
     private void initTimeSetProperty()  {
        try {
@@ -54,27 +54,38 @@
 
-    // needs to be set at XML-reading time,
-    // no runtime action
+    /**
+     * Needs to be set at XML-reading time,
+     * no runtime action.
+     *
+     * @exception BuildException Thrown in unrecoverable error.
+     */
     public void execute() throws BuildException {
     }

cheers,
Kare 8^)

-- 
Kare Nuorteva, programmer
Satama Interactive, Henry Fordin katu 6 FIN-00150 HELSINKI
tel. +3589 680 51 396, GSM +35840 57 833 57
http://www.satama.com/ http://www.satama.de/